@@ -183,8 +183,6 @@ class SvnBaseURL(URLProtocol, SkipDefaultFieldsReprMixin):
     separator: str = dataclasses.field(default="/")
     path: str = dataclasses.field(default="")
 
-    #
-    #
     ref: Optional[str] = None
 
     rule: Optional[str] = None
@@ -353,7 +351,7 @@ class SvnURL(SvnPipURL, SvnBaseURL, URLProtocol, SkipDefaultFieldsReprMixin):
     """
 
     rule_map = RuleMap(
-        _rule_map={m.label: m for m in [*DEFAULT_RULES, *PIP_DEFAULT_RULES]}
+        _rule_map={m.label: m for m in [*DEFAULT_RULES, *PIP_DEFAULT_RULES]},
     )
 
     @classmethod
